# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TopicSchemaTerm(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'for_every_device': 'TopicSchemaForeverydevice',
        'for_every_network_group': 'TopicSchemaForeverynetworkgroup',
        'get_dependencies_from_cache': 'TopicSchemaGetdependenciesfromcache',
        'locate_resource': 'list[TopicSchemaLocateresource]',
        'next': 'bool',
        'term_name': 'str',
        'user_defined_function': 'TopicSchemaUserdefinedfunction',
        'with_capture_group': 'list[TopicSchemaWithcapturegroup]'
    }

    attribute_map = {
        'for_every_device': 'for-every-device',
        'for_every_network_group': 'for-every-network-group',
        'get_dependencies_from_cache': 'get-dependencies-from-cache',
        'locate_resource': 'locate-resource',
        'next': 'next',
        'term_name': 'term-name',
        'user_defined_function': 'user-defined-function',
        'with_capture_group': 'with-capture-group'
    }

    def __init__(self, for_every_device=None, for_every_network_group=None, get_dependencies_from_cache=None, locate_resource=None, next=None, term_name=None, user_defined_function=None, with_capture_group=None):  # noqa: E501
        """TopicSchemaTerm - a model defined in Swagger"""  # noqa: E501

        self._for_every_device = None
        self._for_every_network_group = None
        self._get_dependencies_from_cache = None
        self._locate_resource = None
        self._next = None
        self._term_name = None
        self._user_defined_function = None
        self._with_capture_group = None
        self.discriminator = None

        if for_every_device is not None:
            self.for_every_device = for_every_device
        if for_every_network_group is not None:
            self.for_every_network_group = for_every_network_group
        if get_dependencies_from_cache is not None:
            self.get_dependencies_from_cache = get_dependencies_from_cache
        if locate_resource is not None:
            self.locate_resource = locate_resource
        if next is not None:
            self.next = next
        self.term_name = term_name
        if user_defined_function is not None:
            self.user_defined_function = user_defined_function
        if with_capture_group is not None:
            self.with_capture_group = with_capture_group

    @property
    def for_every_device(self):
        """Gets the for_every_device of this TopicSchemaTerm.  # noqa: E501


        :return: The for_every_device of this TopicSchemaTerm.  # noqa: E501
        :rtype: TopicSchemaForeverydevice
        """
        return self._for_every_device

    @for_every_device.setter
    def for_every_device(self, for_every_device):
        """Sets the for_every_device of this TopicSchemaTerm.


        :param for_every_device: The for_every_device of this TopicSchemaTerm.  # noqa: E501
        :type: TopicSchemaForeverydevice
        """

        self._for_every_device = for_every_device

    @property
    def for_every_network_group(self):
        """Gets the for_every_network_group of this TopicSchemaTerm.  # noqa: E501


        :return: The for_every_network_group of this TopicSchemaTerm.  # noqa: E501
        :rtype: TopicSchemaForeverynetworkgroup
        """
        return self._for_every_network_group

    @for_every_network_group.setter
    def for_every_network_group(self, for_every_network_group):
        """Sets the for_every_network_group of this TopicSchemaTerm.


        :param for_every_network_group: The for_every_network_group of this TopicSchemaTerm.  # noqa: E501
        :type: TopicSchemaForeverynetworkgroup
        """

        self._for_every_network_group = for_every_network_group

    @property
    def get_dependencies_from_cache(self):
        """Gets the get_dependencies_from_cache of this TopicSchemaTerm.  # noqa: E501


        :return: The get_dependencies_from_cache of this TopicSchemaTerm.  # noqa: E501
        :rtype: TopicSchemaGetdependenciesfromcache
        """
        return self._get_dependencies_from_cache

    @get_dependencies_from_cache.setter
    def get_dependencies_from_cache(self, get_dependencies_from_cache):
        """Sets the get_dependencies_from_cache of this TopicSchemaTerm.


        :param get_dependencies_from_cache: The get_dependencies_from_cache of this TopicSchemaTerm.  # noqa: E501
        :type: TopicSchemaGetdependenciesfromcache
        """

        self._get_dependencies_from_cache = get_dependencies_from_cache

    @property
    def locate_resource(self):
        """Gets the locate_resource of this TopicSchemaTerm.  # noqa: E501


        :return: The locate_resource of this TopicSchemaTerm.  # noqa: E501
        :rtype: list[TopicSchemaLocateresource]
        """
        return self._locate_resource

    @locate_resource.setter
    def locate_resource(self, locate_resource):
        """Sets the locate_resource of this TopicSchemaTerm.


        :param locate_resource: The locate_resource of this TopicSchemaTerm.  # noqa: E501
        :type: list[TopicSchemaLocateresource]
        """

        self._locate_resource = locate_resource

    @property
    def next(self):
        """Gets the next of this TopicSchemaTerm.  # noqa: E501

        Continue evaluating next term  # noqa: E501

        :return: The next of this TopicSchemaTerm.  # noqa: E501
        :rtype: bool
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this TopicSchemaTerm.

        Continue evaluating next term  # noqa: E501

        :param next: The next of this TopicSchemaTerm.  # noqa: E501
        :type: bool
        """

        self._next = next

    @property
    def term_name(self):
        """Gets the term_name of this TopicSchemaTerm.  # noqa: E501

        Term name. Should be of pattern [a-zA-Z][a-zA-Z0-9-]*  # noqa: E501

        :return: The term_name of this TopicSchemaTerm.  # noqa: E501
        :rtype: str
        """
        return self._term_name

    @term_name.setter
    def term_name(self, term_name):
        """Sets the term_name of this TopicSchemaTerm.

        Term name. Should be of pattern [a-zA-Z][a-zA-Z0-9-]*  # noqa: E501

        :param term_name: The term_name of this TopicSchemaTerm.  # noqa: E501
        :type: str
        """
        if term_name is None:
            raise ValueError("Invalid value for `term_name`, must not be `None`")  # noqa: E501
        if term_name is not None and len(term_name) > 64:
            raise ValueError("Invalid value for `term_name`, length must be less than or equal to `64`")  # noqa: E501
        if term_name is not None and len(term_name) < 1:
            raise ValueError("Invalid value for `term_name`, length must be greater than or equal to `1`")  # noqa: E501
        if term_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9-]*$', term_name):  # noqa: E501
            raise ValueError(r"Invalid value for `term_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9-]*$/`")  # noqa: E501

        self._term_name = term_name

    @property
    def user_defined_function(self):
        """Gets the user_defined_function of this TopicSchemaTerm.  # noqa: E501


        :return: The user_defined_function of this TopicSchemaTerm.  # noqa: E501
        :rtype: TopicSchemaUserdefinedfunction
        """
        return self._user_defined_function

    @user_defined_function.setter
    def user_defined_function(self, user_defined_function):
        """Sets the user_defined_function of this TopicSchemaTerm.


        :param user_defined_function: The user_defined_function of this TopicSchemaTerm.  # noqa: E501
        :type: TopicSchemaUserdefinedfunction
        """

        self._user_defined_function = user_defined_function

    @property
    def with_capture_group(self):
        """Gets the with_capture_group of this TopicSchemaTerm.  # noqa: E501


        :return: The with_capture_group of this TopicSchemaTerm.  # noqa: E501
        :rtype: list[TopicSchemaWithcapturegroup]
        """
        return self._with_capture_group

    @with_capture_group.setter
    def with_capture_group(self, with_capture_group):
        """Sets the with_capture_group of this TopicSchemaTerm.


        :param with_capture_group: The with_capture_group of this TopicSchemaTerm.  # noqa: E501
        :type: list[TopicSchemaWithcapturegroup]
        """

        self._with_capture_group = with_capture_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TopicSchemaTerm, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TopicSchemaTerm):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from jnpr.healthbot.swagger.models.ca_profile_schema import CaProfileSchema
from jnpr.healthbot.swagger.models.local_certificate_schema import LocalCertificateSchema
from jnpr.healthbot.swagger.models.ssh_key_profile_schema import SshKeyProfileSchema
from jnpr.healthbot.exception import SchemaError, NotFoundError

from jnpr.healthbot.modules import BaseModule

import logging
logger = logging.getLogger(__file__)


class Profile(object):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """

        self._hbot = hbot
        self.data_summarization = DataSummarization(hbot)
        self.security = Security(hbot)


class Security(object):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """

        self._hbot = hbot
        self.ca_profile = CaProfile(hbot)
        self.local_certificate = LocalCertificate(hbot)
        self.ssh_key_profile = SshKeyProfile(hbot)


class CaProfile(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, name: str = None, uncommitted: bool = True):
        """
        Get `CaProfileSchema(s) <jnpr.healthbot.swagger.models.html#caprofileschema>`_ for
        given ca profile name or list for all

        :param name: ID of name
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
            ::
                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.security.ca_profile.get('xyz')

                    # for all
                    print(hb.settings.security.ca_profile.get()

        :return: `CaProfileSchema(s) <jnpr.healthbot.swagger.models.html#caprofileschema>`_
        """
        if name is not None:
            ca_profile_url = self.hbot.urlfor.ca_profile(name)
            if uncommitted:
                ca_profile_url += self.hbot.apiopt_candidate
            response = self.api.get(ca_profile_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(
                response, CaProfileSchema)
        else:
            ca_profiles_url = self.hbot.urlfor.ca_profiles()
            if uncommitted:
                ca_profiles_url += self.hbot.apiopt_candidate
            response = self.api.get(ca_profiles_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_ca_profiles = response_json['ca-profile']
            ca_profiles_list = []
            for ca_profile in existing_ca_profiles:
                obj = self.hbot._create_schema(ca_profile, CaProfileSchema)
                ca_profiles_list.append(obj)

            return ca_profiles_list

    def add(self, schema: CaProfileSchema = None, **kwargs):
        """
        Add ca profile to HealthBot.
        The onus of uploading helper file certificate_authority_crt is on user.
        They should use hb.upload_helper_file API to make sure these crt file
        are uploaded in system.
        We don't do that validation as user can also upload these file after
        configuring profiles.

        :param object schema: `CaProfileSchema <jnpr.healthbot.swagger.models.html#caprofileschema>`_
        :param object kwargs: key values, which can be used to create
            CaProfileSchema
            Check `CaProfileSchema <jnpr.healthbot.swagger.models.html#caprofileschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import CaProfileSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ca_prof_schema = CaProfileSchema(certificate_authority_crt='abc.crt', name='hbez')
                hb.settings.security.ca_profile.add(ca_prof_schema)

        :returns: True when OK

        """
        if schema is None:
            schema = CaProfileSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        ca_profile_url = self.hbot.urlfor.ca_profile(payload['name'])
        response = self.api.post(ca_profile_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, name: str):
        """
        Remove ca profile from security settings

        :param str name: The name of the ca_profile to be deleted

        Example:
        ::
            hb.settings.security.ca_profile.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        ca_profile_url = self.hbot.urlfor.ca_profile(name)
        response = self.api.delete(ca_profile_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: CaProfileSchema = None, **kwargs):
        """
        Update `CaProfileSchema <jnpr.healthbot.swagger.models.html#caprofileschema>`_ for
        given ca profile schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `CaProfileSchema <jnpr.healthbot.swagger.models.html#caprofileschema>`_
        :param object kwargs: key values, which can be used to create
            CaProfileSchema
            Check `CaProfileSchema <jnpr.healthbot.swagger.models.html#caprofileschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.security.ca_profile.get('xyz')
                schemaObj.certificate_authority_crt = 'pqr.crt'
                hb.settings.security.ca_profile.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = CaProfileSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, CaProfileSchema):
                raise SchemaError(CaProfileSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.name
        ca_profile_url = self.hbot.urlfor.ca_profile(name)
        response = call(ca_profile_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class LocalCertificate(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, name: str = None, uncommitted: bool = True):
        """
        Get `LocalCertificateSchema(s) <jnpr.healthbot.swagger.models.html#localcertificateschema>`_ for
        given local certificate name or list for all

        :param name: ID of name
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
            ::
                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.security.local_certificate.get('xyz')

                    # for all
                    print(hb.settings.security.local_certificate.get()

        :return: `LocalCertificateSchema(s) <jnpr.healthbot.swagger.models.html#localcertificateschema>`_
        """
        if name is not None:
            local_cert_url = self.hbot.urlfor.local_certificate(name)
            if uncommitted:
                local_cert_url += self.hbot.apiopt_candidate
            response = self.api.get(local_cert_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(
                response, LocalCertificateSchema)
        else:
            local_certs_url = self.hbot.urlfor.local_certificates()
            if uncommitted:
                local_certs_url += self.hbot.apiopt_candidate
            response = self.api.get(local_certs_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_local_certificates = response_json['local-certificate']
            local_certificates_list = []
            for local_certificate in existing_local_certificates:
                obj = self.hbot._create_schema(local_certificate, LocalCertificateSchema)
                local_certificates_list.append(obj)

            return local_certificates_list

    def add(self, schema: LocalCertificateSchema = None, **kwargs):
        """
        Add local certificate to security settings of HealthBot.
        The onus of uploading helper file (cert and key) is on user.
        They should use hb.upload_helper_file API to make sure these crt/key
        file are uploaded in system.
        We don't do that validation as user can also upload these file after
        configuring profiles.

        :param object schema: `LocalCertificateSchema <jnpr.healthbot.swagger.models.html#localcertificateschema>`_
        :param object kwargs: key values, which can be used to create
            LocalCertificateSchema
            Check `LocalCertificateSchema <jnpr.healthbot.swagger.models.html#localcertificateschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import LocalCertificateSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                local_cert_schema = LocalCertificateSchema(client_crt='abc.crt', client_key='pqr.key', name='hbez')
                hb.settings.security.local_certificate.add(local_cert_schema)

        :returns: True when OK

        """
        if schema is None:
            schema = LocalCertificateSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        local_certificate_url = self.hbot.urlfor.local_certificate(payload['name'])
        response = self.api.post(local_certificate_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, name: str):
        """
        Remove local certificate from security settings

        :param str name: The name of the local_certificate to be deleted

        Example:
        ::
            hb.settings.security.local_certificate.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        local_certificate_url = self.hbot.urlfor.local_certificate(name)
        response = self.api.delete(local_certificate_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: LocalCertificateSchema = None, **kwargs):
        """
        Update `LocalCertificateSchema <jnpr.healthbot.swagger.models.html#localcertificateschema>`_ for
        given local certificate schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `LocalCertificateSchema <jnpr.healthbot.swagger.models.html#localcertificateschema>`_
        :param object kwargs: key values, which can be used to create
            LocalCertificateSchema
            Check `LocalCertificateSchema <jnpr.healthbot.swagger.models.html#localcertificateschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.security.local_certificate.get('xyz')
                schemaObj.client_key = 'xyz.key'
                hb.settings.security.local_certificate.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = LocalCertificateSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, LocalCertificateSchema):
                raise SchemaError(LocalCertificateSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.name
        local_certificate_url = self.hbot.urlfor.local_certificate(name)
        response = call(local_certificate_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class SshKeyProfile(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, name: str = None, uncommitted: bool = True):
        """
        Get `SshKeyProfileSchema(s) <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_ for
        given ssh key profile name or list for all

        :param name: ID of name
        :param bool uncommitted: True includes fetches uncommitted changes,
            False restricts data set to only committed changes

        Example:
            ::
                from jnpr.healthbot import HealthBotClient

                with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                    print(hb.settings.security.ssh_key_profile.get('xyz')

                    # for all
                    print(hb.settings.security.ssh_key_profile.get()

        :return: `SshKeyProfileSchema(s) <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_
        """
        if name is not None:
            ssh_key_profile_url = self.hbot.urlfor.ssh_key_profile(name)
            if uncommitted:
                ssh_key_profile_url += self.hbot.apiopt_candidate
            response = self.api.get(ssh_key_profile_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(
                response, SshKeyProfileSchema)
        else:
            ssh_key_profiles_url = self.hbot.urlfor.ssh_key_profiles()
            if uncommitted:
                ssh_key_profiles_url += self.hbot.apiopt_candidate
            response = self.api.get(ssh_key_profiles_url)
            response_json = response.json()
            if response.status_code != 200:
                logger.error(response.text)
                raise NotFoundError(response_json)
            existing_ssh_key_profiles = response_json['ssh-key-profile']
            ssh_key_profiles_list = []
            for ssh_key_profile in existing_ssh_key_profiles:
                obj = self.hbot._create_schema(ssh_key_profile, SshKeyProfileSchema)
                ssh_key_profiles_list.append(obj)

            return ssh_key_profiles_list

    def add(self, schema: SshKeyProfileSchema = None, **kwargs):
        """
        Add ssh key profile to HealthBot.
        The onus of uploading helper file ssh_private_key_file is on user.
        They should use hb.upload_helper_file API to make sure these key file
        are uploaded in system.
        We don't do that validation as user can also upload these file after
        configuring profiles.

        :param object schema: `SshKeyProfileSchema <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_
        :param object kwargs: key values, which can be used to create
            SshKeyProfileSchema
            Check `SshKeyProfileSchema <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import SshKeyProfileSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                ssh_key_prof_schema = SshKeyProfileSchema(name='hbez', ssh_private_key_file='abc.crt',
                    ssh_private_key_passphrase='%$#@#')
                hb.settings.security.ssh_key_profile.add(ssh_key_prof_schema)

        :returns: True when OK

        """
        if schema is None:
            schema = SshKeyProfileSchema(**kwargs)
        payload = self.hbot._create_payload(schema)
        ssh_key_profile_url = self.hbot.urlfor.ssh_key_profile(payload['name'])
        response = self.api.post(ssh_key_profile_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def delete(self, name: str):
        """
        Remove ssh key profile from security settings

        :param str name: The name of the ssh key profile to be deleted

        Example:
        ::
            hb.settings.security.ssh_key_profile.delete('xyz')
            hb.commit()

        :returns: True when OK
        """

        ssh_key_profile_url = self.hbot.urlfor.ssh_key_profile(name)
        response = self.api.delete(ssh_key_profile_url)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def update(self, schema: SshKeyProfileSchema = None, **kwargs):
        """
        Update `SshKeyProfileSchema <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_ for
        given ssh key profile schema

        Passing Schema invoke `put` and kwargs `post`

        :param obj schema: `SshKeyProfileSchema <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_
        :param object kwargs: key values, which can be used to create
            SshKeyProfileSchema
            Check `SshKeyProfileSchema <jnpr.healthbot.swagger.models.html#sshkeyprofileschema>`_
            for details about which all keys can be used

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.settings.security.ssh_key_profile.get('xyz')
                schemaObj.certificate_authority_crt = 'pqr.crt'
                hb.settings.security.ssh_key_profile.update(schemaObj)

        :returns: True when OK
        """
        if schema is None:
            schema = SshKeyProfileSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, SshKeyProfileSchema):
                raise SchemaError(SshKeyProfileSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        name = schema.name
        ssh_key_profile_url = self.hbot.urlfor.ssh_key_profile(name)
        response = call(ssh_key_profile_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True


class DataSummarization(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)
        self.raw = Raw(hbot)


class Raw(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self): pass

    def add(self): pass

    def delete(self, name: str): pass

    def update(self): pass



# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: healthbot-hackers@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from jnpr.healthbot.swagger.models.scheduler_schema import SchedulerSchema  # noqa: F401,E501
from jnpr.healthbot.swagger.models.systemsettings_schema_systemsettings_reportgeneration import SystemsettingsSchemaSystemsettingsReportgeneration  # noqa: F401,E501


class SystemsettingsSchemaSystemsettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'persist_raw_data': 'list[ERRORUNKNOWN]',
        'report_generation': 'SystemsettingsSchemaSystemsettingsReportgeneration',
        'scheduler': 'list[SchedulerSchema]'
    }

    attribute_map = {
        'persist_raw_data': 'persist-raw-data',
        'report_generation': 'report-generation',
        'scheduler': 'scheduler'
    }

    def __init__(self, persist_raw_data=None, report_generation=None, scheduler=None):  # noqa: E501
        """SystemsettingsSchemaSystemsettings - a model defined in Swagger"""  # noqa: E501

        self._persist_raw_data = None
        self._report_generation = None
        self._scheduler = None
        self.discriminator = None

        if persist_raw_data is not None:
            self.persist_raw_data = persist_raw_data
        if report_generation is not None:
            self.report_generation = report_generation
        if scheduler is not None:
            self.scheduler = scheduler

    @property
    def persist_raw_data(self):
        """Gets the persist_raw_data of this SystemsettingsSchemaSystemsettings.  # noqa: E501

        Persist raw data in the database  # noqa: E501

        :return: The persist_raw_data of this SystemsettingsSchemaSystemsettings.  # noqa: E501
        :rtype: list[ERRORUNKNOWN]
        """
        return self._persist_raw_data

    @persist_raw_data.setter
    def persist_raw_data(self, persist_raw_data):
        """Sets the persist_raw_data of this SystemsettingsSchemaSystemsettings.

        Persist raw data in the database  # noqa: E501

        :param persist_raw_data: The persist_raw_data of this SystemsettingsSchemaSystemsettings.  # noqa: E501
        :type: list[ERRORUNKNOWN]
        """

        self._persist_raw_data = persist_raw_data

    @property
    def report_generation(self):
        """Gets the report_generation of this SystemsettingsSchemaSystemsettings.  # noqa: E501


        :return: The report_generation of this SystemsettingsSchemaSystemsettings.  # noqa: E501
        :rtype: SystemsettingsSchemaSystemsettingsReportgeneration
        """
        return self._report_generation

    @report_generation.setter
    def report_generation(self, report_generation):
        """Sets the report_generation of this SystemsettingsSchemaSystemsettings.


        :param report_generation: The report_generation of this SystemsettingsSchemaSystemsettings.  # noqa: E501
        :type: SystemsettingsSchemaSystemsettingsReportgeneration
        """

        self._report_generation = report_generation

    @property
    def scheduler(self):
        """Gets the scheduler of this SystemsettingsSchemaSystemsettings.  # noqa: E501


        :return: The scheduler of this SystemsettingsSchemaSystemsettings.  # noqa: E501
        :rtype: list[SchedulerSchema]
        """
        return self._scheduler

    @scheduler.setter
    def scheduler(self, scheduler):
        """Sets the scheduler of this SystemsettingsSchemaSystemsettings.


        :param scheduler: The scheduler of this SystemsettingsSchemaSystemsettings.  # noqa: E501
        :type: list[SchedulerSchema]
        """

        self._scheduler = scheduler

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemsettingsSchemaSystemsettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaVector(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'formula': 'RuleSchemaFormula1',
        'path': 'list[str]',
        'time_range': 'str',
        'vector_name': 'str'
    }

    attribute_map = {
        'formula': 'formula',
        'path': 'path',
        'time_range': 'time-range',
        'vector_name': 'vector-name'
    }

    def __init__(self, formula=None, path=None, time_range=None, vector_name=None):  # noqa: E501
        """RuleSchemaVector - a model defined in Swagger"""  # noqa: E501

        self._formula = None
        self._path = None
        self._time_range = None
        self._vector_name = None
        self.discriminator = None

        if formula is not None:
            self.formula = formula
        if path is not None:
            self.path = path
        if time_range is not None:
            self.time_range = time_range
        self.vector_name = vector_name

    @property
    def formula(self):
        """Gets the formula of this RuleSchemaVector.  # noqa: E501


        :return: The formula of this RuleSchemaVector.  # noqa: E501
        :rtype: RuleSchemaFormula1
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """Sets the formula of this RuleSchemaVector.


        :param formula: The formula of this RuleSchemaVector.  # noqa: E501
        :type: RuleSchemaFormula1
        """

        self._formula = formula

    @property
    def path(self):
        """Gets the path of this RuleSchemaVector.  # noqa: E501


        :return: The path of this RuleSchemaVector.  # noqa: E501
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this RuleSchemaVector.


        :param path: The path of this RuleSchemaVector.  # noqa: E501
        :type: list[str]
        """

        self._path = path

    @property
    def time_range(self):
        """Gets the time_range of this RuleSchemaVector.  # noqa: E501

        How much back in time should we look for data. Specify positive integer followed by s/m/h/d/w/y/o representing seconds/minutes/hours/days/weeks/years/offset. Eg: 2s  # noqa: E501

        :return: The time_range of this RuleSchemaVector.  # noqa: E501
        :rtype: str
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this RuleSchemaVector.

        How much back in time should we look for data. Specify positive integer followed by s/m/h/d/w/y/o representing seconds/minutes/hours/days/weeks/years/offset. Eg: 2s  # noqa: E501

        :param time_range: The time_range of this RuleSchemaVector.  # noqa: E501
        :type: str
        """
        if time_range is not None and not re.search(r'^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$', time_range):  # noqa: E501
            raise ValueError(r"Invalid value for `time_range`, must be a follow pattern or equal to `/^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$/`")  # noqa: E501

        self._time_range = time_range

    @property
    def vector_name(self):
        """Gets the vector_name of this RuleSchemaVector.  # noqa: E501

        Name of the vector. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The vector_name of this RuleSchemaVector.  # noqa: E501
        :rtype: str
        """
        return self._vector_name

    @vector_name.setter
    def vector_name(self, vector_name):
        """Sets the vector_name of this RuleSchemaVector.

        Name of the vector. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param vector_name: The vector_name of this RuleSchemaVector.  # noqa: E501
        :type: str
        """
        if vector_name is None:
            raise ValueError("Invalid value for `vector_name`, must not be `None`")  # noqa: E501
        if vector_name is not None and len(vector_name) > 64:
            raise ValueError("Invalid value for `vector_name`, length must be less than or equal to `64`")  # noqa: E501
        if vector_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', vector_name):  # noqa: E501
            raise ValueError(r"Invalid value for `vector_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._vector_name = vector_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaVector, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaVector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaIAgent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'args': 'list[RuleSchemaIAgentArgs]',
        'file': 'str',
        'frequency': 'str',
        'table': 'str',
        'target': 'str'
    }

    attribute_map = {
        'args': 'args',
        'file': 'file',
        'frequency': 'frequency',
        'table': 'table',
        'target': 'target'
    }

    def __init__(self, args=None, file=None, frequency=None, table=None, target=None):  # noqa: E501
        """RuleSchemaIAgent - a model defined in Swagger"""  # noqa: E501

        self._args = None
        self._file = None
        self._frequency = None
        self._table = None
        self._target = None
        self.discriminator = None

        if args is not None:
            self.args = args
        self.file = file
        self.frequency = frequency
        self.table = table
        if target is not None:
            self.target = target

    @property
    def args(self):
        """Gets the args of this RuleSchemaIAgent.  # noqa: E501


        :return: The args of this RuleSchemaIAgent.  # noqa: E501
        :rtype: list[RuleSchemaIAgentArgs]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this RuleSchemaIAgent.


        :param args: The args of this RuleSchemaIAgent.  # noqa: E501
        :type: list[RuleSchemaIAgentArgs]
        """

        self._args = args

    @property
    def file(self):
        """Gets the file of this RuleSchemaIAgent.  # noqa: E501

        File where table and views are defined  # noqa: E501

        :return: The file of this RuleSchemaIAgent.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this RuleSchemaIAgent.

        File where table and views are defined  # noqa: E501

        :param file: The file of this RuleSchemaIAgent.  # noqa: E501
        :type: str
        """
        if file is None:
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def frequency(self):
        """Gets the frequency of this RuleSchemaIAgent.  # noqa: E501

        Frequency at which the iagent should execute the commands and extract the data. Specify positive integer followed by s/m/h/d/w/y representing seconds/minutes/hours/days/weeks/years. Eg: 2s  # noqa: E501

        :return: The frequency of this RuleSchemaIAgent.  # noqa: E501
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this RuleSchemaIAgent.

        Frequency at which the iagent should execute the commands and extract the data. Specify positive integer followed by s/m/h/d/w/y representing seconds/minutes/hours/days/weeks/years. Eg: 2s  # noqa: E501

        :param frequency: The frequency of this RuleSchemaIAgent.  # noqa: E501
        :type: str
        """
        if frequency is None:
            raise ValueError("Invalid value for `frequency`, must not be `None`")  # noqa: E501
        if frequency is not None and not re.search(r'^[1-9][0-9]*[smhdwy]$', frequency):  # noqa: E501
            raise ValueError(r"Invalid value for `frequency`, must be a follow pattern or equal to `/^[1-9][0-9]*[smhdwy]$/`")  # noqa: E501

        self._frequency = frequency

    @property
    def table(self):
        """Gets the table of this RuleSchemaIAgent.  # noqa: E501

        Table which needs to be used to extract the data  # noqa: E501

        :return: The table of this RuleSchemaIAgent.  # noqa: E501
        :rtype: str
        """
        return self._table

    @table.setter
    def table(self, table):
        """Sets the table of this RuleSchemaIAgent.

        Table which needs to be used to extract the data  # noqa: E501

        :param table: The table of this RuleSchemaIAgent.  # noqa: E501
        :type: str
        """
        if table is None:
            raise ValueError("Invalid value for `table`, must not be `None`")  # noqa: E501

        self._table = table

    @property
    def target(self):
        """Gets the target of this RuleSchemaIAgent.  # noqa: E501

        To run command on FPC, specifiy FPC target (optional)  # noqa: E501

        :return: The target of this RuleSchemaIAgent.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this RuleSchemaIAgent.

        To run command on FPC, specifiy FPC target (optional)  # noqa: E501

        :param target: The target of this RuleSchemaIAgent.  # noqa: E501
        :type: str
        """

        self._target = target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaIAgent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaIAgent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TopicSchemaFunction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'argument': 'list[TopicSchemaArgument]',
        'description': 'str',
        'function_name': 'str',
        'method': 'str',
        'path': 'str'
    }

    attribute_map = {
        'argument': 'argument',
        'description': 'description',
        'function_name': 'function-name',
        'method': 'method',
        'path': 'path'
    }

    def __init__(self, argument=None, description=None, function_name=None, method=None, path=None):  # noqa: E501
        """TopicSchemaFunction - a model defined in Swagger"""  # noqa: E501

        self._argument = None
        self._description = None
        self._function_name = None
        self._method = None
        self._path = None
        self.discriminator = None

        if argument is not None:
            self.argument = argument
        if description is not None:
            self.description = description
        self.function_name = function_name
        self.method = method
        self.path = path

    @property
    def argument(self):
        """Gets the argument of this TopicSchemaFunction.  # noqa: E501


        :return: The argument of this TopicSchemaFunction.  # noqa: E501
        :rtype: list[TopicSchemaArgument]
        """
        return self._argument

    @argument.setter
    def argument(self, argument):
        """Sets the argument of this TopicSchemaFunction.


        :param argument: The argument of this TopicSchemaFunction.  # noqa: E501
        :type: list[TopicSchemaArgument]
        """

        self._argument = argument

    @property
    def description(self):
        """Gets the description of this TopicSchemaFunction.  # noqa: E501

        Description of the function  # noqa: E501

        :return: The description of this TopicSchemaFunction.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TopicSchemaFunction.

        Description of the function  # noqa: E501

        :param description: The description of this TopicSchemaFunction.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def function_name(self):
        """Gets the function_name of this TopicSchemaFunction.  # noqa: E501

        Name of the function. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The function_name of this TopicSchemaFunction.  # noqa: E501
        :rtype: str
        """
        return self._function_name

    @function_name.setter
    def function_name(self, function_name):
        """Sets the function_name of this TopicSchemaFunction.

        Name of the function. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param function_name: The function_name of this TopicSchemaFunction.  # noqa: E501
        :type: str
        """
        if function_name is None:
            raise ValueError("Invalid value for `function_name`, must not be `None`")  # noqa: E501
        if function_name is not None and len(function_name) > 64:
            raise ValueError("Invalid value for `function_name`, length must be less than or equal to `64`")  # noqa: E501
        if function_name is not None and len(function_name) < 1:
            raise ValueError("Invalid value for `function_name`, length must be greater than or equal to `1`")  # noqa: E501
        if function_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', function_name):  # noqa: E501
            raise ValueError(r"Invalid value for `function_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._function_name = function_name

    @property
    def method(self):
        """Gets the method of this TopicSchemaFunction.  # noqa: E501

        Function to be called  # noqa: E501

        :return: The method of this TopicSchemaFunction.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this TopicSchemaFunction.

        Function to be called  # noqa: E501

        :param method: The method of this TopicSchemaFunction.  # noqa: E501
        :type: str
        """
        if method is None:
            raise ValueError("Invalid value for `method`, must not be `None`")  # noqa: E501

        self._method = method

    @property
    def path(self):
        """Gets the path of this TopicSchemaFunction.  # noqa: E501

        File in which function is defined. This is relative path to the data directory  # noqa: E501

        :return: The path of this TopicSchemaFunction.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this TopicSchemaFunction.

        File in which function is defined. This is relative path to the data directory  # noqa: E501

        :param path: The path of this TopicSchemaFunction.  # noqa: E501
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TopicSchemaFunction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TopicSchemaFunction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TopicSchemaDependson(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depends_on_multiple_instances': 'bool',
        'description': 'str',
        'resource_name': 'str',
        'term': 'list[TopicSchemaTerm]',
        'triggered_by': 'list[str]',
        'with_capture_group': 'list[TopicSchemaWithcapturegroup]'
    }

    attribute_map = {
        'depends_on_multiple_instances': 'depends-on-multiple-instances',
        'description': 'description',
        'resource_name': 'resource-name',
        'term': 'term',
        'triggered_by': 'triggered-by',
        'with_capture_group': 'with-capture-group'
    }

    def __init__(self, depends_on_multiple_instances=None, description=None, resource_name=None, term=None, triggered_by=None, with_capture_group=None):  # noqa: E501
        """TopicSchemaDependson - a model defined in Swagger"""  # noqa: E501

        self._depends_on_multiple_instances = None
        self._description = None
        self._resource_name = None
        self._term = None
        self._triggered_by = None
        self._with_capture_group = None
        self.discriminator = None

        if depends_on_multiple_instances is not None:
            self.depends_on_multiple_instances = depends_on_multiple_instances
        if description is not None:
            self.description = description
        self.resource_name = resource_name
        self.term = term
        if triggered_by is not None:
            self.triggered_by = triggered_by
        if with_capture_group is not None:
            self.with_capture_group = with_capture_group

    @property
    def depends_on_multiple_instances(self):
        """Gets the depends_on_multiple_instances of this TopicSchemaDependson.  # noqa: E501

        Depends on multiple instances of the depends-on resource. One to many relationship. Eg: ae interface can be dependent on multiple interfaces  # noqa: E501

        :return: The depends_on_multiple_instances of this TopicSchemaDependson.  # noqa: E501
        :rtype: bool
        """
        return self._depends_on_multiple_instances

    @depends_on_multiple_instances.setter
    def depends_on_multiple_instances(self, depends_on_multiple_instances):
        """Sets the depends_on_multiple_instances of this TopicSchemaDependson.

        Depends on multiple instances of the depends-on resource. One to many relationship. Eg: ae interface can be dependent on multiple interfaces  # noqa: E501

        :param depends_on_multiple_instances: The depends_on_multiple_instances of this TopicSchemaDependson.  # noqa: E501
        :type: bool
        """

        self._depends_on_multiple_instances = depends_on_multiple_instances

    @property
    def description(self):
        """Gets the description of this TopicSchemaDependson.  # noqa: E501

        Description about the dependency  # noqa: E501

        :return: The description of this TopicSchemaDependson.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TopicSchemaDependson.

        Description about the dependency  # noqa: E501

        :param description: The description of this TopicSchemaDependson.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def resource_name(self):
        """Gets the resource_name of this TopicSchemaDependson.  # noqa: E501

        Name of dependent resource <topic-name>/<resource-name>. Should be of pattern [a-z][a-z-]*(\\.{1}[a-z0-9-]+)*/[a-z][a-z0-9-]*  # noqa: E501

        :return: The resource_name of this TopicSchemaDependson.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this TopicSchemaDependson.

        Name of dependent resource <topic-name>/<resource-name>. Should be of pattern [a-z][a-z-]*(\\.{1}[a-z0-9-]+)*/[a-z][a-z0-9-]*  # noqa: E501

        :param resource_name: The resource_name of this TopicSchemaDependson.  # noqa: E501
        :type: str
        """
        if resource_name is None:
            raise ValueError("Invalid value for `resource_name`, must not be `None`")  # noqa: E501
        if resource_name is not None and not re.search(r'^[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*\/[a-z][a-z0-9-]*$', resource_name):  # noqa: E501
            raise ValueError(r"Invalid value for `resource_name`, must be a follow pattern or equal to `/^[a-z][a-z-]*(\\.{1}[a-z0-9-]+)*\/[a-z][a-z0-9-]*$/`")  # noqa: E501

        self._resource_name = resource_name

    @property
    def term(self):
        """Gets the term of this TopicSchemaDependson.  # noqa: E501


        :return: The term of this TopicSchemaDependson.  # noqa: E501
        :rtype: list[TopicSchemaTerm]
        """
        return self._term

    @term.setter
    def term(self, term):
        """Sets the term of this TopicSchemaDependson.


        :param term: The term of this TopicSchemaDependson.  # noqa: E501
        :type: list[TopicSchemaTerm]
        """
        if term is None:
            raise ValueError("Invalid value for `term`, must not be `None`")  # noqa: E501

        self._term = term

    @property
    def triggered_by(self):
        """Gets the triggered_by of this TopicSchemaDependson.  # noqa: E501


        :return: The triggered_by of this TopicSchemaDependson.  # noqa: E501
        :rtype: list[str]
        """
        return self._triggered_by

    @triggered_by.setter
    def triggered_by(self, triggered_by):
        """Sets the triggered_by of this TopicSchemaDependson.


        :param triggered_by: The triggered_by of this TopicSchemaDependson.  # noqa: E501
        :type: list[str]
        """

        self._triggered_by = triggered_by

    @property
    def with_capture_group(self):
        """Gets the with_capture_group of this TopicSchemaDependson.  # noqa: E501


        :return: The with_capture_group of this TopicSchemaDependson.  # noqa: E501
        :rtype: list[TopicSchemaWithcapturegroup]
        """
        return self._with_capture_group

    @with_capture_group.setter
    def with_capture_group(self, with_capture_group):
        """Sets the with_capture_group of this TopicSchemaDependson.


        :param with_capture_group: The with_capture_group of this TopicSchemaDependson.  # noqa: E501
        :type: list[TopicSchemaWithcapturegroup]
        """

        self._with_capture_group = with_capture_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TopicSchemaDependson, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TopicSchemaDependson):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicegroupSchemaAuthenticationSsl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ca_profile': 'str',
        'local_certificate': 'str',
        'server_common_name': 'str'
    }

    attribute_map = {
        'ca_profile': 'ca-profile',
        'local_certificate': 'local-certificate',
        'server_common_name': 'server-common-name'
    }

    def __init__(self, ca_profile=None, local_certificate=None, server_common_name=None):  # noqa: E501
        """DevicegroupSchemaAuthenticationSsl - a model defined in Swagger"""  # noqa: E501

        self._ca_profile = None
        self._local_certificate = None
        self._server_common_name = None
        self.discriminator = None

        self.ca_profile = ca_profile
        if local_certificate is not None:
            self.local_certificate = local_certificate
        self.server_common_name = server_common_name

    @property
    def ca_profile(self):
        """Gets the ca_profile of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501

        Name of the ca-profile to be used  # noqa: E501

        :return: The ca_profile of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501
        :rtype: str
        """
        return self._ca_profile

    @ca_profile.setter
    def ca_profile(self, ca_profile):
        """Sets the ca_profile of this DevicegroupSchemaAuthenticationSsl.

        Name of the ca-profile to be used  # noqa: E501

        :param ca_profile: The ca_profile of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501
        :type: str
        """
        if ca_profile is None:
            raise ValueError("Invalid value for `ca_profile`, must not be `None`")  # noqa: E501

        self._ca_profile = ca_profile

    @property
    def local_certificate(self):
        """Gets the local_certificate of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501

        Name of the local-certificate-profile to be used  # noqa: E501

        :return: The local_certificate of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501
        :rtype: str
        """
        return self._local_certificate

    @local_certificate.setter
    def local_certificate(self, local_certificate):
        """Sets the local_certificate of this DevicegroupSchemaAuthenticationSsl.

        Name of the local-certificate-profile to be used  # noqa: E501

        :param local_certificate: The local_certificate of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501
        :type: str
        """

        self._local_certificate = local_certificate

    @property
    def server_common_name(self):
        """Gets the server_common_name of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501

        Common name used while creating server certificate  # noqa: E501

        :return: The server_common_name of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501
        :rtype: str
        """
        return self._server_common_name

    @server_common_name.setter
    def server_common_name(self, server_common_name):
        """Sets the server_common_name of this DevicegroupSchemaAuthenticationSsl.

        Common name used while creating server certificate  # noqa: E501

        :param server_common_name: The server_common_name of this DevicegroupSchemaAuthenticationSsl.  # noqa: E501
        :type: str
        """
        if server_common_name is None:
            raise ValueError("Invalid value for `server_common_name`, must not be `None`")  # noqa: E501

        self._server_common_name = server_common_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicegroupSchemaAuthenticationSsl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicegroupSchemaAuthenticationSsl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class LogsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def retrieve_logs_for_device_group(self, device_group_name, **kwargs):  # noqa: E501
        """Logs for the given device-group.  # noqa: E501

        Get the logs for all the services for the given {device_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_device_group(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Device group name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_logs_for_device_group_with_http_info(device_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_logs_for_device_group_with_http_info(device_group_name, **kwargs)  # noqa: E501
            return data

    def retrieve_logs_for_device_group_with_http_info(self, device_group_name, **kwargs):  # noqa: E501
        """Logs for the given device-group.  # noqa: E501

        Get the logs for all the services for the given {device_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_device_group_with_http_info(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Device group name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_group_name', 'x_iam_token', 'download', 'filename']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_logs_for_device_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_group_name' is set
        if ('device_group_name' not in params or
                params['device_group_name'] is None):
            raise ValueError("Missing the required parameter `device_group_name` when calling `retrieve_logs_for_device_group`")  # noqa: E501

        if ('filename' in params and
                len(params['filename']) > 64):
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_device_group`, length must be less than or equal to `64`")  # noqa: E501
        if 'filename' in params and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', params['filename']):  # noqa: E501
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_device_group`, must conform to the pattern `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'device_group_name' in params:
            path_params['device_group_name'] = params['device_group_name']  # noqa: E501

        query_params = []
        if 'download' in params:
            query_params.append(('download', params['download']))  # noqa: E501
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/gzip', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/logs/device-group/{device_group_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_logs_for_device_group_service(self, device_group_name, service_name, **kwargs):  # noqa: E501
        """Get the logs for the given service running for the given device-group.  # noqa: E501

        Get the logs for the service {service_name} for the given {device_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_device_group_service(device_group_name, service_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Device group name (required)
        :param str service_name: Device-group service name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :param int number_of_lines: Number of lines to show from the end of the logs
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_logs_for_device_group_service_with_http_info(device_group_name, service_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_logs_for_device_group_service_with_http_info(device_group_name, service_name, **kwargs)  # noqa: E501
            return data

    def retrieve_logs_for_device_group_service_with_http_info(self, device_group_name, service_name, **kwargs):  # noqa: E501
        """Get the logs for the given service running for the given device-group.  # noqa: E501

        Get the logs for the service {service_name} for the given {device_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_device_group_service_with_http_info(device_group_name, service_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Device group name (required)
        :param str service_name: Device-group service name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :param int number_of_lines: Number of lines to show from the end of the logs
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_group_name', 'service_name', 'x_iam_token', 'download', 'filename', 'number_of_lines']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_logs_for_device_group_service" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_group_name' is set
        if ('device_group_name' not in params or
                params['device_group_name'] is None):
            raise ValueError("Missing the required parameter `device_group_name` when calling `retrieve_logs_for_device_group_service`")  # noqa: E501
        # verify the required parameter 'service_name' is set
        if ('service_name' not in params or
                params['service_name'] is None):
            raise ValueError("Missing the required parameter `service_name` when calling `retrieve_logs_for_device_group_service`")  # noqa: E501

        if ('filename' in params and
                len(params['filename']) > 64):
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_device_group_service`, length must be less than or equal to `64`")  # noqa: E501
        if 'filename' in params and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', params['filename']):  # noqa: E501
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_device_group_service`, must conform to the pattern `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501
        if 'number_of_lines' in params and params['number_of_lines'] > 100000:  # noqa: E501
            raise ValueError("Invalid value for parameter `number_of_lines` when calling `retrieve_logs_for_device_group_service`, must be a value less than or equal to `100000`")  # noqa: E501
        if 'number_of_lines' in params and params['number_of_lines'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `number_of_lines` when calling `retrieve_logs_for_device_group_service`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'device_group_name' in params:
            path_params['device_group_name'] = params['device_group_name']  # noqa: E501
        if 'service_name' in params:
            path_params['service_name'] = params['service_name']  # noqa: E501

        query_params = []
        if 'download' in params:
            query_params.append(('download', params['download']))  # noqa: E501
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501
        if 'number_of_lines' in params:
            query_params.append(('number_of_lines', params['number_of_lines']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/gzip', 'application/json', 'text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/logs/device-group/{device_group_name}/service/{service_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_logs_for_network_group(self, network_group_name, **kwargs):  # noqa: E501
        """Logs for the given network group.  # noqa: E501

        Get the logs for the service {service_name} for the given {network_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_network_group(network_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Network group name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_logs_for_network_group_with_http_info(network_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_logs_for_network_group_with_http_info(network_group_name, **kwargs)  # noqa: E501
            return data

    def retrieve_logs_for_network_group_with_http_info(self, network_group_name, **kwargs):  # noqa: E501
        """Logs for the given network group.  # noqa: E501

        Get the logs for the service {service_name} for the given {network_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_network_group_with_http_info(network_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Network group name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['network_group_name', 'x_iam_token', 'download', 'filename']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_logs_for_network_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'network_group_name' is set
        if ('network_group_name' not in params or
                params['network_group_name'] is None):
            raise ValueError("Missing the required parameter `network_group_name` when calling `retrieve_logs_for_network_group`")  # noqa: E501

        if ('filename' in params and
                len(params['filename']) > 64):
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_network_group`, length must be less than or equal to `64`")  # noqa: E501
        if 'filename' in params and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', params['filename']):  # noqa: E501
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_network_group`, must conform to the pattern `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'network_group_name' in params:
            path_params['network_group_name'] = params['network_group_name']  # noqa: E501

        query_params = []
        if 'download' in params:
            query_params.append(('download', params['download']))  # noqa: E501
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/gzip', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/logs/network-group/{network_group_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_logs_for_network_group_service(self, network_group_name, service_name, **kwargs):  # noqa: E501
        """Get the logs for the given service running for the given network-group.  # noqa: E501

        Get the logs for all the services for the given {network_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_network_group_service(network_group_name, service_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Network group name (required)
        :param str service_name: Network group service name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :param int number_of_lines: Number of lines to show from the end of the logs
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_logs_for_network_group_service_with_http_info(network_group_name, service_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_logs_for_network_group_service_with_http_info(network_group_name, service_name, **kwargs)  # noqa: E501
            return data

    def retrieve_logs_for_network_group_service_with_http_info(self, network_group_name, service_name, **kwargs):  # noqa: E501
        """Get the logs for the given service running for the given network-group.  # noqa: E501

        Get the logs for all the services for the given {network_group_name}  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_logs_for_network_group_service_with_http_info(network_group_name, service_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str network_group_name: Network group name (required)
        :param str service_name: Network group service name (required)
        :param str x_iam_token: authentication header object
        :param bool download: Download the logs
        :param str filename: Name of the log file
        :param int number_of_lines: Number of lines to show from the end of the logs
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['network_group_name', 'service_name', 'x_iam_token', 'download', 'filename', 'number_of_lines']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_logs_for_network_group_service" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'network_group_name' is set
        if ('network_group_name' not in params or
                params['network_group_name'] is None):
            raise ValueError("Missing the required parameter `network_group_name` when calling `retrieve_logs_for_network_group_service`")  # noqa: E501
        # verify the required parameter 'service_name' is set
        if ('service_name' not in params or
                params['service_name'] is None):
            raise ValueError("Missing the required parameter `service_name` when calling `retrieve_logs_for_network_group_service`")  # noqa: E501

        if ('filename' in params and
                len(params['filename']) > 64):
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_network_group_service`, length must be less than or equal to `64`")  # noqa: E501
        if 'filename' in params and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', params['filename']):  # noqa: E501
            raise ValueError("Invalid value for parameter `filename` when calling `retrieve_logs_for_network_group_service`, must conform to the pattern `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501
        if 'number_of_lines' in params and params['number_of_lines'] > 100000:  # noqa: E501
            raise ValueError("Invalid value for parameter `number_of_lines` when calling `retrieve_logs_for_network_group_service`, must be a value less than or equal to `100000`")  # noqa: E501
        if 'number_of_lines' in params and params['number_of_lines'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `number_of_lines` when calling `retrieve_logs_for_network_group_service`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'network_group_name' in params:
            path_params['network_group_name'] = params['network_group_name']  # noqa: E501
        if 'service_name' in params:
            path_params['service_name'] = params['service_name']  # noqa: E501

        query_params = []
        if 'download' in params:
            query_params.append(('download', params['download']))  # noqa: E501
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501
        if 'number_of_lines' in params:
            query_params.append(('number_of_lines', params['number_of_lines']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/gzip', 'application/json', 'text/plain'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/logs/network-group/{network_group_name}/service/{service_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'platform_name': 'str',
        'releases': 'list[RuleSchemaRulepropertiesSupporteddevicesJuniperReleases]',
        'sensors': 'list[str]'
    }

    attribute_map = {
        'platform_name': 'platform-name',
        'releases': 'releases',
        'sensors': 'sensors'
    }

    def __init__(self, platform_name=None, releases=None, sensors=None):  # noqa: E501
        """RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms - a model defined in Swagger"""  # noqa: E501

        self._platform_name = None
        self._releases = None
        self._sensors = None
        self.discriminator = None

        self.platform_name = platform_name
        if releases is not None:
            self.releases = releases
        if sensors is not None:
            self.sensors = sensors

    @property
    def platform_name(self):
        """Gets the platform_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501

        Platform name, Ex: MX960. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The platform_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501
        :rtype: str
        """
        return self._platform_name

    @platform_name.setter
    def platform_name(self, platform_name):
        """Sets the platform_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.

        Platform name, Ex: MX960. Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param platform_name: The platform_name of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501
        :type: str
        """
        if platform_name is None:
            raise ValueError("Invalid value for `platform_name`, must not be `None`")  # noqa: E501
        if platform_name is not None and len(platform_name) > 64:
            raise ValueError("Invalid value for `platform_name`, length must be less than or equal to `64`")  # noqa: E501
        if platform_name is not None and len(platform_name) < 1:
            raise ValueError("Invalid value for `platform_name`, length must be greater than or equal to `1`")  # noqa: E501
        if platform_name is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', platform_name):  # noqa: E501
            raise ValueError(r"Invalid value for `platform_name`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._platform_name = platform_name

    @property
    def releases(self):
        """Gets the releases of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501

        Release information for the products  # noqa: E501

        :return: The releases of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501
        :rtype: list[RuleSchemaRulepropertiesSupporteddevicesJuniperReleases]
        """
        return self._releases

    @releases.setter
    def releases(self, releases):
        """Sets the releases of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.

        Release information for the products  # noqa: E501

        :param releases: The releases of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501
        :type: list[RuleSchemaRulepropertiesSupporteddevicesJuniperReleases]
        """

        self._releases = releases

    @property
    def sensors(self):
        """Gets the sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501


        :return: The sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501
        :rtype: list[str]
        """
        return self._sensors

    @sensors.setter
    def sensors(self, sensors):
        """Sets the sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.


        :param sensors: The sensors of this RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms.  # noqa: E501
        :type: list[str]
        """

        self._sensors = sensors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class AuthenticationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def refresh_token(self, token, **kwargs):  # noqa: E501
        """Re-issue tokens from existing token  # noqa: E501

        Re-issue tokens from existing token  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refresh_token(token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Token token: Token object (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.refresh_token_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.refresh_token_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def refresh_token_with_http_info(self, token, **kwargs):  # noqa: E501
        """Re-issue tokens from existing token  # noqa: E501

        Re-issue tokens from existing token  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refresh_token_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Token token: Token object (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method refresh_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `refresh_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'token' in params:
            body_params = params['token']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/token/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_login(self, credential, **kwargs):  # noqa: E501
        """User login  # noqa: E501

        User login and recive tokens  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_login(credential, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Credential credential: topics body object (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_login_with_http_info(credential, **kwargs)  # noqa: E501
        else:
            (data) = self.user_login_with_http_info(credential, **kwargs)  # noqa: E501
            return data

    def user_login_with_http_info(self, credential, **kwargs):  # noqa: E501
        """User login  # noqa: E501

        User login and recive tokens  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_login_with_http_info(credential, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Credential credential: topics body object (required)
        :return: InlineResponse2002
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credential']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_login" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credential' is set
        if ('credential' not in params or
                params['credential'] is None):
            raise ValueError("Missing the required parameter `credential` when calling `user_login`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'credential' in params:
            body_params = params['credential']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/login/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2002',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_logout(self, refresh_token, **kwargs):  # noqa: E501
        """User logout  # noqa: E501

        User logout  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_logout(refresh_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RefreshToken refresh_token: request body object (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_logout_with_http_info(refresh_token, **kwargs)  # noqa: E501
        else:
            (data) = self.user_logout_with_http_info(refresh_token, **kwargs)  # noqa: E501
            return data

    def user_logout_with_http_info(self, refresh_token, **kwargs):  # noqa: E501
        """User logout  # noqa: E501

        User logout  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_logout_with_http_info(refresh_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RefreshToken refresh_token: request body object (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['refresh_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_logout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'refresh_token' is set
        if ('refresh_token' not in params or
                params['refresh_token'] is None):
            raise ValueError("Missing the required parameter `refresh_token` when calling `user_logout`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'refresh_token' in params:
            body_params = params['refresh_token']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/logout/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from jnpr.healthbot.swagger.models.rule_schema import RuleSchema
from jnpr.healthbot.swagger.models.topic_schema import TopicSchema
from jnpr.healthbot.exception import SchemaError, NotFoundError

from jnpr.healthbot.modules import BaseModule
import logging
logger = logging.getLogger(__file__)


class Rule(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def add(self, topic_name: str, schema: RuleSchema = None, **kwargs):
        """
        Create Rule under given topic

        :param str topic_name: Rules to be created under this given topic name
        :param object schema: `RuleSchema <jnpr.healthbot.swagger.models.html#ruleschema>`_
        :param object kwargs: key values, which can be used to create
            RuleSchema
            Check `RuleSchema <jnpr.healthbot.swagger.models.html#ruleschema>`_
            for details about which all keys can be used

        Example:
        ::
            from jnpr.healthbot import HealthBotClient
            from jnpr.healthbot import RuleSchema

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                rs = RuleSchema(rule_name="hbez-fpc-heap-utilization")

                rs.description = "HealthBot EZ example"
                rs.synopsis = "Using python client for demo"


                rs.sensor = [{'description': 'Monitors FPC buffer, heap and cpu utilization',
                              'iAgent': {'file': 'fpc-utilization.yml',
                                         'frequency': '30s',
                                         'table': 'FPCCPUHEAPutilizationTable'},
                              'sensor-name': 'fpccpuheaputilization'}]

                from jnpr.healthbot.swagger.models.rule_schema_field import RuleSchemaField
                from jnpr.healthbot.swagger.models.rule_schema_constant import RuleSchemaConstant

                rs.field = [RuleSchemaField(constant=RuleSchemaConstant(value='{{fpc-buffer-usage-threshold}}'),
                                            description='This field is for buffer usage threshold',
                                            field_name='linecard-buffer-usage-threshold'),
                            RuleSchemaField(constant=RuleSchemaConstant(value='{{fpc-cpu-usage-threshold}}'),
                                            description='This field is for linecard cpu usage threshold',
                                            field_name='linecard-cpu-usage-threshold'),
                            RuleSchemaField(constant=RuleSchemaConstant(value='{{fpc-heap-usage-threshold}}'),
                                            description='This field is for linecard heap usage threshold',
                                            field_name='linecard-heap-usage-threshold')]

                rs.keys = ['slot']

                rs.variable = [{'description': 'Linecard Buffer Memory usage threshold value',
                                'name': 'fpc-buffer-usage-threshold',
                                'type': 'int',
                                'value': '80'},
                               {'description': 'Linecard CPU usage threshold value',
                                'name': 'fpc-cpu-usage-threshold',
                                'type': 'int',
                                'value': '80'},
                               {'description': 'Linecard Heap Memory usage threshold value',
                                'name': 'fpc-heap-usage-threshold',
                                'type': 'int',
                                'value': '80'}]

                rs.trigger = [{'description': 'Sets health based on linecard buffer memory',
                               'frequency': '60s',
                               'synopsis': 'Linecard buffer memory kpi',
                               'term': [{'term-name': 'is-buffer-memory-utilization-greater-than-threshold',
                                         'then': {'status': {'color': 'red',
                                                             'message': 'FPC buffer memory '
                                                                        'utilization '
                                                                        '($memory-buffer-utilization) '
                                                                        'is over threshold '
                                                                        '($linecard-buffer-usage-threshold)'}},
                                         'when': {'greater-than': [{'left-operand': '$memory-buffer-utilization',
                                                                    'right-operand': '$linecard-buffer-usage-threshold'}]}},
                                        {'term-name': 'buffer-utilization-less-than-threshold',
                                         'then': {'status': {'color': 'green'}}}],
                               'trigger-name': 'fpc-buffer-memory-utilization'},
                              {'description': 'Sets health based on linecard cpu utilization',
                               'frequency': '60s',
                               'synopsis': 'Linecard cpu utilization kpi',
                               'term': [{'term-name': 'is-cpu-utilization-greater-than-80',
                                         'then': {'status': {'color': 'red',
                                                             'message': 'FPC CPU utilization '
                                                                        '($cpu-total) is over '
                                                                        'threshold '
                                                                        '($linecard-cpu-usage-threshold)'}},
                                         'when': {'greater-than': [{'left-operand': '$cpu-total',
                                                                    'right-operand': '$linecard-cpu-usage-threshold',
                                                                    'time-range': '180s'}]}},
                                        {'term-name': 'cpu-utilization-less-than-threshold',
                                         'then': {'status': {'color': 'green'}}}],
                               'trigger-name': 'fpc-cpu-utilization'},
                              {'description': 'Sets health based on linecard heap memory '
                                              'utilization',
                               'frequency': '60s',
                               'synopsis': 'Linecard heap memory kpi',
                               'term': [{'term-name': 'is-heap-memory-utilization-greater-than-threshold',
                                         'then': {'status': {'color': 'red',
                                                             'message': 'FPC heap memory '
                                                                        'utilization '
                                                                        '($memory-heap-utilization) '
                                                                        'is over threshold '
                                                                        '($linecard-heap-usage-threshold)'}},
                                         'when': {'greater-than': [{'left-operand': '$memory-heap-utilization',
                                                                    'right-operand': '$linecard-heap-usage-threshold'}]}},
                                        {'term-name': 'heap-memory-utilization-less-than-threshold',
                                         'then': {'status': {'color': 'green'}}}],
                               'trigger-name': 'fpc-heap-memory-utilization'}]
                hb.rule.add('hbez', schema=rs)

        Returns:
            True if action successful

        """
        if schema is None:
            schema = RuleSchema(**kwargs)
        else:
            if not isinstance(schema, RuleSchema):
                raise SchemaError(RuleSchema)

        # check for topic presence, if not do all that first
        topic_url = self.hbot.urlfor.topic(topic_name)
        resp = self.api.get(topic_url + self.hbot.apiopt_candidate)
        if not resp.ok:
            logger.debug(
                "Adding topic '{}' first as its not present".format(topic_name))
            response = self.api.post(topic_url, json={"topic-name":
                                                      topic_name})
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()

        payload = self.hbot._create_payload(schema)
        rule_url = self.hbot.urlfor.rule(topic_name, payload['rule-name'])
        resp = self.api.get(rule_url + self.hbot.apiopt_candidate)
        if resp.ok:
            logger.info("Rule already exists")
            return True
        response = self.api.post(rule_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()

        return True

    def delete(self, topic_name: str, rule_name: str):
        """
        Delete rule under given topic

        :param str topic_name: The name of the topic under which rule need to deleted
        :param str rule_name: The name of the rule to be deleted

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                hb.rule.delete('linecard.ospf', 'check-ddos-statistics')

        """

        payload = {'rule-name': rule_name}
        rule_url = self.hbot.urlfor.rule(topic_name, rule_name)
        response = self.api.delete(rule_url, json=payload)
        if response.status_code != 204:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def get(
            self,
            topic_name: str,
            rule_name: str = None,
            uncommitted: bool = True):
        """
        get rule(s) details under given topic

        :param str topic_name: The name of the topic under which rule need to be fetched
        :param str rule_name: The name of the rule under given topic
                If none return list for all Rule
        :param bool uncommitted: True includes fetches uncommitted changes,
                False restricts data set to only committed changes

        Example:
        ::
            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.rule.get('linecard.ospf', 'check-ddos-statistics')

                print(hb.rule.get('linecard.ospf')

        """
        if rule_name is not None:
            rule_url = self.hbot.urlfor.rule(topic_name, rule_name)
            if uncommitted:
                rule_url += self.hbot.apiopt_candidate
            response = self.api.get(rule_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, RuleSchema)
        else:
            response = self.hbot.topic.get(topic_name)
            response_json = response.to_dict()
            rule_list = []
            existing_rules = response_json['rule']
            for rule in existing_rules:
                obj = self.hbot._create_schema(rule, RuleSchema)
                rule_list.append(obj)
            return rule_list

    def update(self, topic_name: str, schema: RuleSchema = None, **kwargs):
        """
        Update `RuleSchema <jnpr.healthbot.swagger.models.html#ruleschema>`_ for
        given rule schema object

        Passing Schema invoke `put` and kwargs `post`

        :param str topic_name: The name of the topic under which rule need to be updated
        :param obj schema: `RuleSchema <jnpr.healthbot.swagger.models.html#ruleschema>`_
        :param object kwargs: key values, which can be used to create
            RuleSchema

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                schemaObj = hb.rule.get(topic_name='hbez', rule_name="hbez-fpc-heap-utilization")
                schemaObj.description = "HbEZ example"
                hb.rule.update(topic_name='hbez', schemaObj)

        :returns: True when OK

        """
        if schema is None:
            schema = RuleSchema(**kwargs)
            call = self.api.post
        else:
            if not isinstance(schema, RuleSchema):
                raise SchemaError(RuleSchema)
            call = self.api.put
        payload = self.hbot._create_payload(schema)
        rule_url = self.hbot.urlfor.rule(topic_name, payload['rule-name'])
        response = call(rule_url, json=payload)
        if response.status_code != 200:
            logger.error(response.text)
        response.raise_for_status()
        return True

    def upload_rule_file(self, filename):
        """

        :param filename: File to be loaded
        :return: return True of OK
        """
        return self.hbot.upload_helper_file(filename)


class Topic(BaseModule):

    def __init__(self, hbot):
        """
        :param object hbot: :class:`jnpr.healthbot.HealthBotClient` client instance
        """
        super().__init__(hbot)

    def get(self, topic_name: str = None, uncommitted: bool = True):
        """
        Get `TopicSchema(s) <jnpr.healthbot.swagger.models.html#topicschema>`_
         for given topic name or all topics in HealthBot system

        Example:
        ::

            from jnpr.healthbot import HealthBotClient

            with HealthBotClient('xx.xxx.x.xx', 'xxxx', 'xxxx') as hb:
                print(hb.topic.get('linecard.ospf'))
                topics = hb.topic.get()
                for topic in topics:
                    print(topic)

        :return: Single/list of `TopicSchema <jnpr.healthbot.swagger.models.html#topicchema>`_
        """
        if topic_name is not None:
            topic_url = self.hbot.urlfor.topic(topic_name)
            if uncommitted:
                topic_url += self.hbot.apiopt_candidate
            response = self.api.get(topic_url)
            if response.status_code != 200:
                logger.error(response.text)
            response.raise_for_status()
            return self.hbot._create_schema(response, TopicSchema)
        else:
            topic_list = []

            topic_list_url = self.hbot.urlfor.topics()
            resp = self.api.get(topic_list_url)

            if resp.status_code == 404:
                return False

            existing_topics = resp.json()['topic']
            for topic in existing_topics:
                obj = self.hbot._create_schema(topic, TopicSchema)
                topic_list.append(obj)

            return topic_list



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaRulepropertiesSupporteddevicesOthervendor(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'apply_macro': 'list[ApplyMacroSchema]',
        'operating_system': 'str',
        'operating_systems': 'list[RuleSchemaRulepropertiesSupporteddevicesOperatingsystems]',
        'sensors': 'list[str]',
        'vendor_identifier': 'str',
        'vendor_name': 'str'
    }

    attribute_map = {
        'apply_macro': 'apply-macro',
        'operating_system': 'operating-system',
        'operating_systems': 'operating-systems',
        'sensors': 'sensors',
        'vendor_identifier': 'vendor-identifier',
        'vendor_name': 'vendor-name'
    }

    def __init__(self, apply_macro=None, operating_system=None, operating_systems=None, sensors=None, vendor_identifier=None, vendor_name=None):  # noqa: E501
        """RuleSchemaRulepropertiesSupporteddevicesOthervendor - a model defined in Swagger"""  # noqa: E501

        self._apply_macro = None
        self._operating_system = None
        self._operating_systems = None
        self._sensors = None
        self._vendor_identifier = None
        self._vendor_name = None
        self.discriminator = None

        if apply_macro is not None:
            self.apply_macro = apply_macro
        if operating_system is not None:
            self.operating_system = operating_system
        if operating_systems is not None:
            self.operating_systems = operating_systems
        if sensors is not None:
            self.sensors = sensors
        self.vendor_identifier = vendor_identifier
        self.vendor_name = vendor_name

    @property
    def apply_macro(self):
        """Gets the apply_macro of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501


        :return: The apply_macro of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :rtype: list[ApplyMacroSchema]
        """
        return self._apply_macro

    @apply_macro.setter
    def apply_macro(self, apply_macro):
        """Sets the apply_macro of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.


        :param apply_macro: The apply_macro of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :type: list[ApplyMacroSchema]
        """

        self._apply_macro = apply_macro

    @property
    def operating_system(self):
        """Gets the operating_system of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501

        [Deprecated] Vendor operating system, Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :return: The operating_system of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :rtype: str
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """Sets the operating_system of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.

        [Deprecated] Vendor operating system, Should be of pattern [a-zA-Z][a-zA-Z0-9_-]*  # noqa: E501

        :param operating_system: The operating_system of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :type: str
        """
        if operating_system is not None and len(operating_system) > 64:
            raise ValueError("Invalid value for `operating_system`, length must be less than or equal to `64`")  # noqa: E501
        if operating_system is not None and len(operating_system) < 1:
            raise ValueError("Invalid value for `operating_system`, length must be greater than or equal to `1`")  # noqa: E501
        if operating_system is not None and not re.search(r'^[a-zA-Z][a-zA-Z0-9_-]*$', operating_system):  # noqa: E501
            raise ValueError(r"Invalid value for `operating_system`, must be a follow pattern or equal to `/^[a-zA-Z][a-zA-Z0-9_-]*$/`")  # noqa: E501

        self._operating_system = operating_system

    @property
    def operating_systems(self):
        """Gets the operating_systems of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501

        Operating system of the device  # noqa: E501

        :return: The operating_systems of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :rtype: list[RuleSchemaRulepropertiesSupporteddevicesOperatingsystems]
        """
        return self._operating_systems

    @operating_systems.setter
    def operating_systems(self, operating_systems):
        """Sets the operating_systems of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.

        Operating system of the device  # noqa: E501

        :param operating_systems: The operating_systems of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :type: list[RuleSchemaRulepropertiesSupporteddevicesOperatingsystems]
        """

        self._operating_systems = operating_systems

    @property
    def sensors(self):
        """Gets the sensors of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501


        :return: The sensors of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :rtype: list[str]
        """
        return self._sensors

    @sensors.setter
    def sensors(self, sensors):
        """Sets the sensors of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.


        :param sensors: The sensors of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :type: list[str]
        """

        self._sensors = sensors

    @property
    def vendor_identifier(self):
        """Gets the vendor_identifier of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501

        Unique key to identify the other vendor specific products  # noqa: E501

        :return: The vendor_identifier of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :rtype: str
        """
        return self._vendor_identifier

    @vendor_identifier.setter
    def vendor_identifier(self, vendor_identifier):
        """Sets the vendor_identifier of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.

        Unique key to identify the other vendor specific products  # noqa: E501

        :param vendor_identifier: The vendor_identifier of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :type: str
        """
        if vendor_identifier is None:
            raise ValueError("Invalid value for `vendor_identifier`, must not be `None`")  # noqa: E501
        if vendor_identifier is not None and len(vendor_identifier) > 64:
            raise ValueError("Invalid value for `vendor_identifier`, length must be less than or equal to `64`")  # noqa: E501
        if vendor_identifier is not None and len(vendor_identifier) < 1:
            raise ValueError("Invalid value for `vendor_identifier`, length must be greater than or equal to `1`")  # noqa: E501

        self._vendor_identifier = vendor_identifier

    @property
    def vendor_name(self):
        """Gets the vendor_name of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501

        Vendor name  # noqa: E501

        :return: The vendor_name of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :rtype: str
        """
        return self._vendor_name

    @vendor_name.setter
    def vendor_name(self, vendor_name):
        """Sets the vendor_name of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.

        Vendor name  # noqa: E501

        :param vendor_name: The vendor_name of this RuleSchemaRulepropertiesSupporteddevicesOthervendor.  # noqa: E501
        :type: str
        """
        if vendor_name is None:
            raise ValueError("Invalid value for `vendor_name`, must not be `None`")  # noqa: E501
        if vendor_name is not None and len(vendor_name) > 64:
            raise ValueError("Invalid value for `vendor_name`, length must be less than or equal to `64`")  # noqa: E501
        if vendor_name is not None and len(vendor_name) < 1:
            raise ValueError("Invalid value for `vendor_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._vendor_name = vendor_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaRulepropertiesSupporteddevicesOthervendor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaRulepropertiesSupporteddevicesOthervendor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WorkflowStatisticsSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'total_run': 'int',
        'total_succeeded': 'int',
        'total_failed': 'int',
        'total_running': 'int',
        'total_suspended': 'int'
    }

    attribute_map = {
        'description': 'description',
        'total_run': 'total_run',
        'total_succeeded': 'total_succeeded',
        'total_failed': 'total_failed',
        'total_running': 'total_running',
        'total_suspended': 'total_suspended'
    }

    def __init__(self, description=None, total_run=None, total_succeeded=None, total_failed=None, total_running=None, total_suspended=None):  # noqa: E501
        """WorkflowStatisticsSchema - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._total_run = None
        self._total_succeeded = None
        self._total_failed = None
        self._total_running = None
        self._total_suspended = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if total_run is not None:
            self.total_run = total_run
        if total_succeeded is not None:
            self.total_succeeded = total_succeeded
        if total_failed is not None:
            self.total_failed = total_failed
        if total_running is not None:
            self.total_running = total_running
        if total_suspended is not None:
            self.total_suspended = total_suspended

    @property
    def description(self):
        """Gets the description of this WorkflowStatisticsSchema.  # noqa: E501

        Description about this workflow statistics  # noqa: E501

        :return: The description of this WorkflowStatisticsSchema.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowStatisticsSchema.

        Description about this workflow statistics  # noqa: E501

        :param description: The description of this WorkflowStatisticsSchema.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def total_run(self):
        """Gets the total_run of this WorkflowStatisticsSchema.  # noqa: E501

        Total workflow instances run  # noqa: E501

        :return: The total_run of this WorkflowStatisticsSchema.  # noqa: E501
        :rtype: int
        """
        return self._total_run

    @total_run.setter
    def total_run(self, total_run):
        """Sets the total_run of this WorkflowStatisticsSchema.

        Total workflow instances run  # noqa: E501

        :param total_run: The total_run of this WorkflowStatisticsSchema.  # noqa: E501
        :type: int
        """
        if total_run is not None and total_run < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_run`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_run = total_run

    @property
    def total_succeeded(self):
        """Gets the total_succeeded of this WorkflowStatisticsSchema.  # noqa: E501

        Total workflow instances succeeded  # noqa: E501

        :return: The total_succeeded of this WorkflowStatisticsSchema.  # noqa: E501
        :rtype: int
        """
        return self._total_succeeded

    @total_succeeded.setter
    def total_succeeded(self, total_succeeded):
        """Sets the total_succeeded of this WorkflowStatisticsSchema.

        Total workflow instances succeeded  # noqa: E501

        :param total_succeeded: The total_succeeded of this WorkflowStatisticsSchema.  # noqa: E501
        :type: int
        """
        if total_succeeded is not None and total_succeeded < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_succeeded`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_succeeded = total_succeeded

    @property
    def total_failed(self):
        """Gets the total_failed of this WorkflowStatisticsSchema.  # noqa: E501

        Total workflow instances failed  # noqa: E501

        :return: The total_failed of this WorkflowStatisticsSchema.  # noqa: E501
        :rtype: int
        """
        return self._total_failed

    @total_failed.setter
    def total_failed(self, total_failed):
        """Sets the total_failed of this WorkflowStatisticsSchema.

        Total workflow instances failed  # noqa: E501

        :param total_failed: The total_failed of this WorkflowStatisticsSchema.  # noqa: E501
        :type: int
        """
        if total_failed is not None and total_failed < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_failed`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_failed = total_failed

    @property
    def total_running(self):
        """Gets the total_running of this WorkflowStatisticsSchema.  # noqa: E501

        Total workflow instances running currently  # noqa: E501

        :return: The total_running of this WorkflowStatisticsSchema.  # noqa: E501
        :rtype: int
        """
        return self._total_running

    @total_running.setter
    def total_running(self, total_running):
        """Sets the total_running of this WorkflowStatisticsSchema.

        Total workflow instances running currently  # noqa: E501

        :param total_running: The total_running of this WorkflowStatisticsSchema.  # noqa: E501
        :type: int
        """
        if total_running is not None and total_running < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_running`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_running = total_running

    @property
    def total_suspended(self):
        """Gets the total_suspended of this WorkflowStatisticsSchema.  # noqa: E501

        Total workflow instances suspended  # noqa: E501

        :return: The total_suspended of this WorkflowStatisticsSchema.  # noqa: E501
        :rtype: int
        """
        return self._total_suspended

    @total_suspended.setter
    def total_suspended(self, total_suspended):
        """Sets the total_suspended of this WorkflowStatisticsSchema.

        Total workflow instances suspended  # noqa: E501

        :param total_suspended: The total_suspended of this WorkflowStatisticsSchema.  # noqa: E501
        :type: int
        """
        if total_suspended is not None and total_suspended < 0:  # noqa: E501
            raise ValueError("Invalid value for `total_suspended`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_suspended = total_suspended

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowStatisticsSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowStatisticsSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FlowSchemaFlowTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'key_fields': 'list[str]',
        'name': 'str',
        'priority': 'int',
        'protocol_version': 'str',
        'recognition_pattern': 'FlowSchemaFlowRecognitionpattern'
    }

    attribute_map = {
        'description': 'description',
        'key_fields': 'key-fields',
        'name': 'name',
        'priority': 'priority',
        'protocol_version': 'protocol-version',
        'recognition_pattern': 'recognition-pattern'
    }

    def __init__(self, description=None, key_fields=None, name=None, priority=None, protocol_version=None, recognition_pattern=None):  # noqa: E501
        """FlowSchemaFlowTemplate - a model defined in Swagger"""  # noqa: E501

        self._description = None
        self._key_fields = None
        self._name = None
        self._priority = None
        self._protocol_version = None
        self._recognition_pattern = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if key_fields is not None:
            self.key_fields = key_fields
        self.name = name
        if priority is not None:
            self.priority = priority
        if protocol_version is not None:
            self.protocol_version = protocol_version
        if recognition_pattern is not None:
            self.recognition_pattern = recognition_pattern

    @property
    def description(self):
        """Gets the description of this FlowSchemaFlowTemplate.  # noqa: E501

        Template description.  # noqa: E501

        :return: The description of this FlowSchemaFlowTemplate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FlowSchemaFlowTemplate.

        Template description.  # noqa: E501

        :param description: The description of this FlowSchemaFlowTemplate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def key_fields(self):
        """Gets the key_fields of this FlowSchemaFlowTemplate.  # noqa: E501


        :return: The key_fields of this FlowSchemaFlowTemplate.  # noqa: E501
        :rtype: list[str]
        """
        return self._key_fields

    @key_fields.setter
    def key_fields(self, key_fields):
        """Sets the key_fields of this FlowSchemaFlowTemplate.


        :param key_fields: The key_fields of this FlowSchemaFlowTemplate.  # noqa: E501
        :type: list[str]
        """

        self._key_fields = key_fields

    @property
    def name(self):
        """Gets the name of this FlowSchemaFlowTemplate.  # noqa: E501

        Name of the template.  # noqa: E501

        :return: The name of this FlowSchemaFlowTemplate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FlowSchemaFlowTemplate.

        Name of the template.  # noqa: E501

        :param name: The name of this FlowSchemaFlowTemplate.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def priority(self):
        """Gets the priority of this FlowSchemaFlowTemplate.  # noqa: E501

        Priority given to template during matching.  # noqa: E501

        :return: The priority of this FlowSchemaFlowTemplate.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this FlowSchemaFlowTemplate.

        Priority given to template during matching.  # noqa: E501

        :param priority: The priority of this FlowSchemaFlowTemplate.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def protocol_version(self):
        """Gets the protocol_version of this FlowSchemaFlowTemplate.  # noqa: E501

        Flow protocol version.  # noqa: E501

        :return: The protocol_version of this FlowSchemaFlowTemplate.  # noqa: E501
        :rtype: str
        """
        return self._protocol_version

    @protocol_version.setter
    def protocol_version(self, protocol_version):
        """Sets the protocol_version of this FlowSchemaFlowTemplate.

        Flow protocol version.  # noqa: E501

        :param protocol_version: The protocol_version of this FlowSchemaFlowTemplate.  # noqa: E501
        :type: str
        """
        allowed_values = ["v9", "v10"]  # noqa: E501
        if protocol_version not in allowed_values:
            raise ValueError(
                "Invalid value for `protocol_version` ({0}), must be one of {1}"  # noqa: E501
                .format(protocol_version, allowed_values)
            )

        self._protocol_version = protocol_version

    @property
    def recognition_pattern(self):
        """Gets the recognition_pattern of this FlowSchemaFlowTemplate.  # noqa: E501


        :return: The recognition_pattern of this FlowSchemaFlowTemplate.  # noqa: E501
        :rtype: FlowSchemaFlowRecognitionpattern
        """
        return self._recognition_pattern

    @recognition_pattern.setter
    def recognition_pattern(self, recognition_pattern):
        """Sets the recognition_pattern of this FlowSchemaFlowTemplate.


        :param recognition_pattern: The recognition_pattern of this FlowSchemaFlowTemplate.  # noqa: E501
        :type: FlowSchemaFlowRecognitionpattern
        """

        self._recognition_pattern = recognition_pattern

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FlowSchemaFlowTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FlowSchemaFlowTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
